@@ -27,6 +27,7 @@
 
 import datetime
 import hubzero.config.passwords
+import hubzero.utilities.misc
 import hubzero.config.webconfig
 import hubzero.data.db
 import ldap
@@ -102,15 +103,16 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	db.execQuery(sql, data)
 
 
-def _insert_jos_xprofiles(db, hubname, uid, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber):
+def _insert_jos_xprofiles(db, hubname, uid, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
+	
 	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
 	sql += "`mailPreferenceOption`, `usageAgreement`, `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
 	sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
 	sql += "VALUES (" + '%s,'*37 + "%s );" 
 	
-	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, '/home/' + hubname + "/" + username, '', 
-	        '', hubzero.config.passwords.MD5PasswordHash(pw), gid, 'public', '', '', '', '', '', '', 
+	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+	        '/usr/lib/sftp-server', hubzero.config.passwords.MD5PasswordHash(pw), gid, '', '', '', '', '', '', '', 
 	        0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
 	        '', '', fname, '', lname, '', 0, 0, '', '', None)
 	db.execQuery(sql, data)
@@ -135,6 +137,14 @@ def _insert_jos_xgroups(db, name, description):
 	return gidNumber
 
 
+def _insert_jos_xgroups_memers(db, gidNumber, uidNumber):
+	sql =  "INSERT INTO jos_xgroups ( gidNumber, uidNumber "
+	sql += "VALUES ( %s, %s );" 
+
+	data = (gidNumber, uidNumber)
+	gidNumber = db.execQuery(sql, data)
+
+
 def _del_jos_xgroups(db, name):
 	sql = "DELETE FROM jos_xgroups WHERE `CN`=%s "
 	data = (name)
@@ -178,9 +188,10 @@ def _del_ldap_group(groupName):
 def _add_ldap_user(username, password):
 
 	# get ldapManagerUserDN and PW
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrPW")	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPAcctMgrDN")	
-	hubLDAPBaseDN = hubzero.config.webconfig.getWebConfigOption("hubLDAPBaseDN")
+	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
+	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -191,6 +202,11 @@ def _add_ldap_user(username, password):
 	attrs['cn'] = username
 	attrs['userPassword'] = "none"
 	attrs['uid'] = username
+	
+	print "add ldap user dn: " + dn
+	print "ldif: "
+	print attrs
+	
 	ldif = ldap.modlist.addModlist(attrs)
 	l.add_s(dn, ldif)
 
@@ -216,19 +232,13 @@ def delhubgroup(groupName):
 	_del_jos_xgroups(db, groupName)
 
 
-def addhubgroup(groupName):
-	# grab config options
-	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", dbPW, "myhub")
+def addhubgroup(db, groupName, groupDescription):
+
+	gidNumber = _insert_jos_xgroups(db, groupName, groupDescription)
+	return gidNumber
+
 	
-	gidNumber = _insert_jos_xgroups(db, groupName, groupName)
-	
-	print "gidNumber = " + str(gidNumber)
-	
-	_add_ldap_group(groupName, groupName, gidNumber)
-	
-	
-def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, skipldap):
+def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, homeDir, createGroup, skipldap):
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -238,13 +248,41 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 	
 	fullname = fname + ' ' + lname
 
+	# usually homeDir will be blank, but not always
+	if homeDir == "":
+		homeDir = '/home/' + hubname + "/" + username
+
+
 	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-	_insert_jos_xprofiles(db, hubname, userID, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber)
+	_insert_jos_xprofiles(db, hubname, userID, fname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
 	_insert_jos_users_password(db, userID, pw)
+
+
+	# create linux group for user named same as username
+	if createGroup:
+		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["addgroup", username])
+		print procStdOut
+		if rc:
+			print procStdErr
+		gidNumber = _insert_jos_xgroups(db, name, description)	
+		_insert_jos_xgroups_memers(gidNumber, userID)
+		
+
+	# create home directory
+	rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["mkdir", homeDir, "--mode", "0750"])
+	print procStdOut
+	if rc:
+		print procStdErr
+
 	
-	# TODO add password table entry
+	# set ownerships
+	rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
+	print procStdOut
+	if rc:
+		print procStdErr
+
 	
 	if not skipldap:
 		_add_ldap_user(username, pw)
